@@ -17,7 +17,10 @@ from windmill.bin import admin_lib
 import logging
 import functest
 import transforms
-import simplejson
+try:
+    import json as simplejson
+except:
+    import simplejson
 import os, sys, re
 from time import sleep
 
@@ -25,7 +28,7 @@ logger = logging.getLogger(__name__)
 
 class NSWrapper(object):
     def __init__(self, ):
-        pass
+        pass        
         
 def setup_module(module):
     """setup_module function for functest based python tests"""
@@ -34,7 +37,7 @@ def setup_module(module):
     
     import windmill
     if not hasattr(windmill, 'settings'):
-        admin_lib.configure_global_settings()
+        admin_lib.configure_global_settings(logging_on=False)
     
     if functest.registry.get('url', False):
         windmill.settings['TEST_URL'] = functest.registry['url']
@@ -120,6 +123,14 @@ class WindmillFunctestRunner(functest.runner.FunctestRunnerInterface):
     def test_function_failed(self, test):
         logger.error('Functest test failed: '+test.__name__)
 
+class WindmillTestClientException(AssertionError):
+    def __init__(self, result):
+        self.result = result
+    def __str__(self):
+        self.result.pop('version', None)
+        self.result['params'].pop('uuid', None)
+        return repr(self.result)
+
 class WindmillTestClient(object):
     """Windmill controller implementation for python test authoring library"""
     assertions = True
@@ -178,26 +189,30 @@ class WindmillTestClient(object):
         # We'll need to start the suite for the name passed to the initializer
         self._method_proxy.start_suite(suite_name)
                         
-    def _exec_command(self, command_name, **kwargs):
+    def _exec_command(self, command_name, assertion=None, **kwargs):
         """Execute command, if browser_debugging then just add it to queue"""
+        if assertion is None:
+            assertion = self.assertions
         command = {'method':command_name, 'params':kwargs}
         if not self.browser_debugging:
             result = self._method_proxy.execute_command({'method':command_name, 'params':kwargs})
-            if not result and self.assertions:
-                assert result['result']
+            if not result and assertion:
+                raise WindmillTestClientException(result)
             else:
                 return result['result']
         else:
             return self._method_proxy.add_command({'method':command_name, 'params':kwargs})
             
 
-    def _exec_test(self, test_name, **kwargs):
+    def _exec_test(self, test_name, assertion=None, **kwargs):
         """Execute test, if browser_debugging then just add it to queue"""
+        if assertion is None:
+            assertion = self.assertions
         test = {'method':test_name, 'params':kwargs}
         if not self.browser_debugging:
             result = self._method_proxy.execute_test({'method':test_name, 'params':kwargs})
-            if not result['result']['result'] and self.assertions:
-                assert result['result']['result']
+            if not result['result']['result'] and assertion:
+                raise WindmillTestClientException(result['result'])
             else:
                 return result['result']
         else:
