@@ -5,7 +5,13 @@ import socket
 import threading
 from django.core.handlers.wsgi import WSGIHandler
 from django.core.servers import basehttp
-from django.test.testcases import call_command, TestCase
+from django.test.testcases import call_command
+ 
+# support both django 1.0 and 1.1
+try:
+    from django.test.testcases import TransactionTestCase as TestCase
+except ImportError:
+    from django.test.testcases import TestCase
 
 class StoppableWSGIServer(basehttp.WSGIServer):
     """WSGIServer with short timeout, so that server thread can stop this server."""
@@ -39,8 +45,16 @@ class TestServerThread(threading.Thread):
         """Sets up test server and database and loops over handling http requests."""
         try:
             handler = basehttp.AdminMediaHandler(WSGIHandler())
-            server_address = (self.address, self.port)
-            httpd = StoppableWSGIServer(server_address, basehttp.WSGIRequestHandler)
+            httpd = None
+            while httpd is None:
+                try:
+                    server_address = (self.address, self.port)
+                    httpd = StoppableWSGIServer(server_address, basehttp.WSGIRequestHandler)
+                except basehttp.WSGIServerException, e:
+                    if "Address already in use" in str(e):
+                        self.port +=1
+                    else:
+                        raise e
             httpd.set_app(handler)
             self.started.set()
         except basehttp.WSGIServerException, e:
@@ -63,6 +77,7 @@ class TestServerThread(threading.Thread):
         # Loop until we get a stop event.
         while not self._stopevent.isSet():
             httpd.handle_request()
+        httpd.server_close()
 
     def join(self, timeout=None):
         """Stop the thread and wait for it to finish."""
@@ -90,11 +105,14 @@ TestCase.stop_test_server = classmethod(stop_test_server)
 from windmill.authoring import unit
 
 class WindmillDjangoUnitTest(TestCase, unit.WindmillUnitTestCase):
-    test_url = 'http://localhost:8000'
+    test_port = 8000
     def setUp(self):
-        self.start_test_server('localhost', 8000)
+        self.start_test_server('localhost', self.test_port)
+        self.test_url = 'http://localhost:%d' % self.server_thread.port
         unit.WindmillUnitTestCase.setUp(self)
 
     def tearDown(self):
         unit.WindmillUnitTestCase.tearDown(self)
         self.stop_test_server()
+
+WindmillDjangoTransactionUnitTest = WindmillDjangoUnitTest
