@@ -19,7 +19,7 @@ def findInPath(fileName, path=os.environ['PATH']):
     for dir in dirs:
         if os.path.isfile(os.path.join(dir, fileName)):
             return os.path.join(dir, fileName)
-        if os.name == 'nt' or sys.platform == 'cygwin':
+        if sys.platform in ('cygwin', 'win32'):
             if os.path.isfile(os.path.join(dir, fileName + ".exe")):
                 return os.path.join(dir, fileName + ".exe")
     return None
@@ -37,7 +37,7 @@ WINDMILL_PATH    = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
 JS_PATH          = os.path.join(WINDMILL_PATH, 'html')
 SAVES_PATH       = None
 EXTENSIONS_DIR   = None
-COMPRESS_JS      = True
+DISABLE_JS_COMPRESS      = False
 
 TEST_URL  = 'http://tutorial.getwindmill.com/'
 
@@ -51,6 +51,7 @@ BROWSER_DEBUGGING   = False
 START_FIREFOX       = False
 START_IE            = False
 START_SAFARI        = False
+START_CHROME        = False
 
 JAVASCRIPT_TEST_DIR = None
 JAVASCRIPT_TEST_FILTER = None
@@ -103,8 +104,19 @@ if PLATFORM == 'darwin':
 #         if os.path.isdir(path):
 #             MOZILLA_DEFAULT_PROFILE = path
 
-elif os.name == 'nt' or sys.platform == 'cygwin':
-    IE_BINARY  = os.path.join(os.environ['ProgramFiles'], 'Internet Explorer', 'iexplore.exe')
+elif sys.platform in ('cygwin', 'win32'):
+    if sys.platform == 'cygwin':
+        program_files = os.environ['PROGRAMFILES']
+    else:
+        program_files = os.environ['ProgramFiles']
+    IE_BINARY  = os.path.join(program_files, 'Internet Explorer', 'iexplore.exe')
+    
+    if os.path.isfile(os.path.join(program_files, 'Safari', 'Safari.exe')):
+        SAFARI_BINARY = os.path.join(program_files, 'Safari', 'Safari.exe')
+        
+    if os.path.isfile(os.path.join(os.path.expanduser('~'), 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')):
+        CHROME_BINARY = os.path.join(os.path.expanduser('~'), 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')
+    
     # firefoxBin = findInPath('firefox')
     # 
     # if firefoxBin is None:
