@@ -1048,7 +1048,7 @@ windmill.controller = new function () {
   */
   this.execJsInTestWindow = function(paramObject){
     var js = paramObject.js;
-    return eval.call(windmill.testWin(), js);
+    return windmill.testWin().eval(js);
   };
   this.execArbTestWinJS = this.execJsInTestWindow;
   
@@ -1060,5 +1060,9 @@ windmill.controller = new function () {
     var js = paramObject.js;
     return eval.call(window, js);
   };
-};
-
+  
+  this.triggerEvent = function(paramObject){
+    var element = lookupNode(paramObject);
+    windmill.events.triggerEvent(element, paramObject.option, true);
+  };
+};
\ No newline at end of file
