@@ -39,41 +39,14 @@ windmill.xhr = new function() {
     //action callback
     this.actionHandler = function(str) {
         //Process variables but not for the execJS or execIDEJS
-        var origStr = str;
-        str = unescape(str);
         if ((str.indexOf('execJsInTestWindow') == -1) && (str.indexOf('execArbTestWinJS') == -1) && (str.indexOf('execIDEJS') == -1)){
           str = windmill.xhr.processVar(str);
         }
         
-        //cleanup, apparently json parsers don't like \"
-        //str = str.replace(/\\"/g, "\'")
-        
         //Eval 
         try {
-          if (typeof(JSON) != "undefined"){
-            windmill.xhr.xhrResponse = JSON.parse(str);
-          }
-          else {
-            windmill.xhr.xhrResponse = fleegix.json.parse(str);
-          }
-        } catch (err){
-            //if the escaped string breaks everything, use the unescaped string
-            try {
-              if (typeof(JSON) != "undefined"){
-                windmill.xhr.xhrResponse = JSON.parse(origStr);
-              }
-              else {
-                windmill.xhr.xhrResponse = fleegix.json.parse(origStr);
-              }
-            //if we can't get an object, bail
-            } catch(err){
-              windmill.out("<span style='color:red;'>\""+err + "\". (Did you escape all double quotes?)</span>")
-              jQuery('#tabs').tabs("select", 1);
-              windmill.err(err);
-              windmill.xhr.getNext();
-              return; 
-            }
-        }
+          windmill.xhr.xhrResponse = JSON.parse(str);
+        } catch (err){ return; }
         
         var resp = windmill.xhr.xhrResponse;
         var method = resp.result.method;
@@ -240,7 +213,7 @@ windmill.xhr = new function() {
         };
         
         //send the report
-        var result_string = fleegix.json.serialize(windmill.xhr.xhrResponse.result);
+        var result_string = JSON.stringify(windmill.xhr.xhrResponse.result);
         var test_obj = {
             "result": result,
             "output": typeof(output) !== "undefined" ? output : null,
@@ -251,7 +224,7 @@ windmill.xhr = new function() {
         };
         var jsonObject = new jsonCall('1.1', 'report');
         jsonObject.params = test_obj;
-        var jsonString = fleegix.json.serialize(jsonObject);
+        var jsonString = JSON.stringify(jsonObject);
         //Actually send the report
         fleegix.xhr.doPost(reportHandler, '/windmill-jsonrpc/', jsonString);
     };
@@ -267,7 +240,7 @@ windmill.xhr = new function() {
         
         if (windmill.xhr.loopState) {
             var jsonObject = new jsonCall('1.1', 'next_action');
-            var jsonString = fleegix.json.serialize(jsonObject);
+            var jsonString = JSON.stringify(jsonObject);
 
             //Execute the post to get the next action
             //Set the xhr timeout to be really high
@@ -295,7 +268,7 @@ windmill.xhr = new function() {
         }
         var test_obj = {};
         var jsonObject = new jsonCall('1.1', 'clear_queue');
-        var jsonString = fleegix.json.serialize(jsonObject);
+        var jsonString = JSON.stringify(jsonObject);
         //Actually send the report
         fleegix.xhr.doPost(h, '/windmill-jsonrpc/', jsonString);
 
