@@ -16,7 +16,10 @@
 server interfaces and the browser's js interface"""
 
 import copy, os 
-import simplejson
+try:
+    import json as simplejson
+except:
+    import simplejson
 import logging
 from uuid import uuid1
 import windmill
@@ -41,7 +44,7 @@ class ControllerQueue(object):
         if command['params'].get('priority', None):
             priority = command['params'].pop('priority')
         else:
-            priority = 0
+            priority = None
         
         command['type'] = 'command'
             
@@ -88,18 +91,21 @@ class TestResolutionSuite(object):
         self.resolved = {}
         self.current_suite = None
 
-    def resolve(self, result, uuid, starttime, endtime, debug=None):
+    def resolve(self, result, uuid, starttime, endtime, debug=None, output=None):
         """Resolve test by uuid"""
         test = self.unresolved.pop(uuid)
+        if debug:
+            test['debug'] = debug
         test['result'] = result
         test['starttime'] = starttime
         test['endtime'] = endtime
+        test['output'] = output
         self.resolved[uuid] = test
                 
         if result is False:
-            test_results_logger.error('Test Failure in test %s' % test)
+            test_results_logger.error('Test Failure in test %s' % repr(test))
         elif result is True:
-            test_results_logger.debug('Test Success in test %s' % test)
+            test_results_logger.debug('Test Success in test %s' % repr(test))
         
         if self.result_processor is not None:
             if result is False:
@@ -107,13 +113,13 @@ class TestResolutionSuite(object):
             elif result is True:
                 self.result_processor.success(test, debug=debug)
     
-    def report_without_resolve(self, result, uuid, starttime, endtime, suite_name, debug=None):
+    def report_without_resolve(self, result, uuid, starttime, endtime, suite_name, debug=None, output=None):
         test = {'result':result, 'uuid':uuid, 'starttime':starttime, 'endtime':endtime, 
-                'suite_name':suite_name, 'debug':debug}
+                'suite_name':suite_name, 'debug':debug, 'output':output}
         if result is False:
-            test_results_logger.error('Test Failure in test %s' % test)
+            test_results_logger.error('Test Failure in test %s' % repr(test))
         elif result is True:
-            test_results_logger.debug('Test Success in test %s' % test)
+            test_results_logger.debug('Test Success in test %s' % repr(test))
     
         if self.result_processor is not None:
             if result is False:
@@ -288,13 +294,13 @@ class JSONRPCMethods(RPCMethods):
             action.update({'method':'defer'})
             return action
             
-    def report(self, uuid, result, starttime, endtime, debug=None):
+    def report(self, uuid, result, starttime, endtime, debug=None, output=None):
         """Report fass/fail for a test"""
-        self._test_resolution_suite.resolve(result, uuid, starttime, endtime, debug)
+        self._test_resolution_suite.resolve(result, uuid, starttime, endtime, debug, output)
         return 200
         
-    def report_without_resolve(self, uuid, result, starttime, endtime, suite_name, debug=None):
-        self._test_resolution_suite.report_without_resolve(result, uuid, starttime, endtime, suite_name, debug)
+    def report_without_resolve(self, uuid, result, starttime, endtime, suite_name, debug=None, output=None):
+        self._test_resolution_suite.report_without_resolve(result, uuid, starttime, endtime, suite_name, debug, output)
         return 200
         
     def command_result(self, status, uuid, result):
@@ -326,7 +332,7 @@ class JSONRPCMethods(RPCMethods):
                 test['params'].pop('uuid')
         return windmill.authoring.transforms.registry[transformer](suite_name, tests)
         
-    def teardown(self):
+    def teardown(self, tests):
         """teardown_module function for functest based python tests"""
         import windmill
         if windmill.settings['EXIT_ON_DONE']:
