@@ -18,7 +18,7 @@ from httplib import HTTPConnection
 from urlparse import urlparse
 import copy
 import logging
-
+import urllib
 logger = logging.getLogger(__name__)
 
 # Note that hoppish conntains proxy-connection, which is pre-HTTP-1.1 and is somewhat nebulous
@@ -36,22 +36,55 @@ def is_hop_by_hop(header):
 initial_forwarding_registry = {}
 forwarding_registry = {}
 exclude_from_retry = []
-# 
-# class IterativeResponse(object):
-#     def __init__(self, response_instance):
-#         self.response_instance = response_instance
-#         
-#     def __iter__(self):
-#         if self.response_instance.chunked:
-#             yield self.response_instance.read(1024)
-#             while self.response_instance.chunk_left is not None:
-#                 if self.response_instance.chunk_left < 1024:
-#                     yield self.response_instance.read()
-#                     self.response_instance.chunk_left = None
-#                 else:
-#                     yield self.response_instance.read(1024)
-#         else:
-#             yield self.response_instance.read()
+first_forward_domains = []
+static_forwards = {}
+
+class IterativeResponse(object):
+    def __init__(self, response_instance):
+        self.response_instance = response_instance
+        
+    def __iter__(self):
+        if self.response_instance.chunked:
+            yield self.response_instance.read(1024)
+            while self.response_instance.chunk_left is not None:
+                if self.response_instance.chunk_left < 1024:
+                    yield self.response_instance.read()
+                    self.response_instance.chunk_left = None
+                else:
+                    yield self.response_instance.read(1024)
+        else:
+            yield self.response_instance.read()
+
+def get_wsgi_response(response):
+    if type(response) is str:
+        return [response]
+    if response.length > 1000:
+        return IterativeResponse(response)
+    else:
+        return [response.read()]
+
+def conditions_pass(e):
+    for c in windmill.server.forwarding_conditions:
+        if c(e) is False:
+            return False
+    return True
+
+def proxy_post_redirect_form(environ, action):
+    body = environ['wsgi.input'].read(int(environ['CONTENT_LENGTH']))
+    parameters = body.split('&')
+    inputs = []
+    for parameter in parameters:
+        parts = parameter.split('=', 1)
+        if len(parts) == 1:
+            continue
+        parts = tuple(urllib.unquote(part) for part in parts)
+        inputs.append('<input type="hidden" name="%s" value="%s" />' % parts)
+    form = """<html><head><title>There is no spoon.</title></head>
+<body onload="document.getElementById('redirect').submit();"
+      style="text-align: center;">
+  <form id="redirect" action="%s" method="POST">%s</form>
+</body></html>""" % (action, '\n'.join(inputs))
+    return form
 
 class WindmillProxyApplication(object):
     """Application to handle requests that need to be proxied"""
@@ -78,23 +111,37 @@ class WindmillProxyApplication(object):
         if windmill.settings['FORWARDING_TEST_URL'] is not None and (
            not url.netloc.startswith('localhost') ) and (
            not url.netloc.startswith('127.0.0.1') ) and (
-           reduce(lambda x, y: x == y(environ), windmill.server.forwarding_conditions, True)):
+           conditions_pass(environ) ):
             # Do our domain change magic
             url = urlparse(environ['reconstructed_url'])
             
             test_netloc = urlparse(windmill.settings['FORWARDING_TEST_URL']).netloc
             referer = environ.get('HTTP_REFERER', None)
 
-            if ( url.netloc != test_netloc ):
+            if ( url.netloc in static_forwards.keys() ):
+                host_netloc = static_forwards[url.netloc]
+                forwarding_registry[url.geturl()] = host_netloc
+                environ = change_environ_domain(url.netloc, host_netloc, environ)
+                url = urlparse(url.geturl().replace(url.netloc, host_netloc))
+
+            elif ( url.netloc != test_netloc ):
                 # if the url's network address is not the test URL that has been set we need to return
                 # a forward
-                initial_forwarding_registry[url.geturl().replace(url.netloc, test_netloc, 1)] = url.netloc
-                response = 'Windmill is forwarding you to a new url at the proper test domain'
-                start_response("302 Found", [('Content-Type', 'text/plain',), 
-                                             ('Content-Length', str(len(response)),),
-                                             ('Location', url.geturl().replace(url.netloc, test_netloc,), 
-                                             )])
-                logger.debug('New domain request, forwarded to '+url.geturl().replace(url.netloc, test_netloc))
+                redirect_url = url.geturl().replace(url.netloc, test_netloc, 1)
+                initial_forwarding_registry[redirect_url] = url.netloc
+                if environ['REQUEST_METHOD'] == 'POST':
+                    response = proxy_post_redirect_form(environ, redirect_url)
+                    start_response("200 Ok", [('Content-Type', 'text/html',), 
+                                              ('Content-Length', str(len(response)),),
+                                              ])
+                    logger.debug('New POST domain request, forwarded to ' + redirect_url)
+                else:
+                    response = 'Windmill is forwarding you to a new url at the proper test domain'
+                    start_response("302 Found", [('Content-Type', 'text/plain',), 
+                                                 ('Content-Length', str(len(response)),),
+                                                 ('Location', redirect_url,)
+                                                 ])
+                    logger.debug('New domain request, forwarded to ' + redirect_url)
                 return [response]
         
             elif ( url.geturl() in initial_forwarding_registry.keys() ):
@@ -124,9 +171,12 @@ class WindmillProxyApplication(object):
 
             # Read in request body if it exists    
             body = None
-            if environ.get('CONTENT_LENGTH'):
+            if environ.has_key('body'):
+                body = environ['body']
+            elif environ.get('CONTENT_LENGTH'):
                 length = int(environ['CONTENT_LENGTH'])
                 body = environ['wsgi.input'].read(length)
+                environ['body'] = body
 
             # Build headers
             headers = {}
@@ -165,6 +215,7 @@ class WindmillProxyApplication(object):
             # retry the given request against all the hosts the current session has run against
             nhosts = copy.copy(initial_forwarding_registry.values())
             nhosts.reverse()
+            nhosts = first_forward_domains + nhosts
             hosts = [];
             # Can't use set() here because it needs to keep it's original ordering.
             for h in nhosts:
@@ -188,7 +239,7 @@ class WindmillProxyApplication(object):
                 response = new_response
             else:
                 start_response(*connection.pop(0))
-                return [connection.pop(0)]
+                return get_wsgi_response(connection.pop(0))
         else:
             response = connection.getresponse()
         
@@ -204,9 +255,8 @@ class WindmillProxyApplication(object):
         headers = self.parse_headers(response)
         if response.status == 404:
             logger.info('Could not fullfill proxy request to '+url.geturl()+'. '+str(set(initial_forwarding_registry.values())))
-        result = response.read()
         start_response(response.status.__str__()+' '+response.reason, headers)
-        return [result]
+        return get_wsgi_response(response)
 
     def parse_headers(self, response):
         headers = [ (x.lower(), y,) for x, y in [ z.split(':', 1) for z in str(response.msg).splitlines() if ':' in z]]
